@@ -1,7 +1,7 @@
 package asset_test
 
 import (
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	. "github.com/achannarasappa/ticker/internal/asset"
