@@ -1,7 +1,7 @@
 package currency_test
 
 import (
-	. "github.com/onsi/ginkgo"
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 
 	c "github.com/achannarasappa/ticker/internal/common"
